.. |bowl| image:: docs/source/django-chili.png

===================================
|bowl| Welcome to Django Chili!
===================================

.. overview_start

**Django Chili** is a Django extension that enables the use of static HTML files as Django
templates. It's designed for scenarios where UI designs are created using
tools like Figma/Anima or Bootstrap Studio and need to be integrated into Django projects.
The extension adds tags to Django that can load static HTML files and uses CSS selectors
to transform and decorate them into Django templates. This allows developers to work on the
Django logic separately, without altering the original HTML that designers are producing.

.. overview_end


Documentation
  https://docs.django-chili.io/en/latest/
